@@ -48,7 +48,7 @@ GIT_ABBREV_LENGTH = 12
 # If the text "$Format" is still present, it means that
 # git archive did not replace the $Format string, which
 # means that this not a git archive.
-GIT_EXPORT_SUBST_H = '4fc139a85bcdfcffb816a42fdc99b55cd7657f94'
+GIT_EXPORT_SUBST_H = 'f7c4a74874d938bcb54c261423682ad793f0305a'
 GIT_EXPORT_SUBST_D = ''
 IS_GIT_ARCHIVE = not GIT_EXPORT_SUBST_H.startswith('$Format')
 
@@ -88,14 +88,6 @@ def update_cmakelists_txt(src_dir, set_version, repo_data):
                                 f"set(STRATOSHARK_MINOR_VERSION {repo_data['ss_version_minor']})",
                                 new_cmake_contents,
                                 flags=re.MULTILINE)
-    new_cmake_contents = re.sub(r"^set *\( *STRATOSHARK_PATCH_VERSION *\d+ *\)$",
-                                f"set(STRATOSHARK_PATCH_VERSION {repo_data['ss_version_patch']})",
-                                new_cmake_contents,
-                                flags=re.MULTILINE)
-    new_cmake_contents = re.sub(r"^set *\( *STRATOSHARK_VERSION_EXTENSION .*?$",
-                                f"set(STRATOSHARK_VERSION_EXTENSION \"{repo_data['ss_package_string']}\")",
-                                new_cmake_contents,
-                                flags=re.MULTILINE)
 
     with open(cmake_filepath, mode='w', encoding='utf-8') as fh:
         fh.write(new_cmake_contents)
@@ -295,7 +287,7 @@ def get_version(cmakelists_file_data, flavor):
     fpfx = 'STRATOSHARK' if flavor == Flavor.Stratoshark else 'PROJECT'
     MAJOR_PATTERN = rf"^set *\( *{fpfx}_MAJOR_VERSION *(\d+) *\)$"
     MINOR_PATTERN = rf"^set *\( *{fpfx}_MINOR_VERSION *(\d+) *\)$"
-    PATCH_PATTERN = rf"^set *\( *{fpfx}_PATCH_VERSION *(\d+) *\)$"
+    PATCH_PATTERN = r"^set *\( *PROJECT_PATCH_VERSION *(\d+) *\)$"
 
     major_match = re.search(MAJOR_PATTERN, cmakelists_file_data, re.MULTILINE)
     minor_match = re.search(MINOR_PATTERN, cmakelists_file_data, re.MULTILINE)
