@@ -1,4 +1,5 @@
-/* expert_info_model.h
+/** @file
+ *
  * Data model for Expert Info tap data.
  *
  * Wireshark - Network traffic analyzer
@@ -38,6 +39,7 @@ public:
     QVariant headerData(int section, Qt::Orientation orientation,
                         int role = Qt::DisplayRole) const;
     int columnCount(const QModelIndex &parent = QModelIndex()) const;
+    bool hasChildren(const QModelIndex &parent = QModelIndex()) const;
 
     virtual bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const;
 
@@ -58,16 +60,3 @@ protected:
 };
 
 #endif // EXPERT_INFO_PROXY_MODEL_H
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
